[cfe-commits] r38735 - /cfe/cfe/trunk/test/Preprocessor/macro_fn_preexpand.c

sabre at cs.uiuc.edu sabre at cs.uiuc.edu
Wed Jul 11 09:24:12 PDT 2007


Author: sabre
Date: Wed Jul 11 11:24:12 2007
New Revision: 38735

URL: http://llvm.org/viewvc/llvm-project?rev=38735&view=rev
Log:
Make this testcase more interesting, actually add run lines :)

Modified:
    cfe/cfe/trunk/test/Preprocessor/macro_fn_preexpand.c

Modified: cfe/cfe/trunk/test/Preprocessor/macro_fn_preexpand.c
URL: http://llvm.org/viewvc/llvm-project/cfe/cfe/trunk/test/Preprocessor/macro_fn_preexpand.c?rev=38735&r1=38734&r2=38735&view=diff

==============================================================================
--- cfe/cfe/trunk/test/Preprocessor/macro_fn_preexpand.c (original)
+++ cfe/cfe/trunk/test/Preprocessor/macro_fn_preexpand.c Wed Jul 11 11:24:12 2007
@@ -1,5 +1,12 @@
-// clang %s -E | grep '1 1 X'
-/* Preexpansion of argument.*/
+// RUN: clang %s -E | grep 'pre: 1 1 X' &&
+// RUN: clang %s -E | grep 'nopre: 1A(X)'
+
+/* Preexpansion of argument. */
 #define A(X) 1 X
-A(A(X))
+pre: A(A(X))
+
+/* The ## operator disables preexpansion. */
+#undef A
+#define A(X) 1 ## X
+nopre: A(A(X))
 





More information about the cfe-commits mailing list